==> generator-jhipster-vmware-clarity-1.0.0.tgz: package/README.md <==
# generator-jhipster-vmware-clarity
[![NPM version][npm-image]][npm-url] [![Build Status][travis-image]][travis-url] [![Dependency Status][daviddm-image]][daviddm-url]
> JHipster module, Clarity Design System for Angular.

# Introduction

This is a [JHipster](http://jhipster.github.io/) module, that is meant to be used in a JHipster application.

# Prerequisites

As this is a [JHipster](http://jhipster.github.io/) module, we expect you have JHipster and its related tools already installed:

- [Installing JHipster](https://jhipster.github.io/installation.html)

# Installation

## With Yarn

To install this module:

```bash
yarn global add generator-jhipster-vmware-clarity
```

To update this module:

```bash
yarn global upgrade generator-jhipster-vmware-clarity
```

## With NPM

To install this module:

```bash
npm install -g generator-jhipster-vmware-clarity
```

To update this module:

```bash
npm update -g generator-jhipster-vmware-clarity
```

# Usage

# License

MIT © [Chiho Sin](https://github.com/chihosin)


[npm-image]: https://img.shields.io/npm/v/generator-jhipster-vmware-clarity.svg
[npm-url]: https://npmjs.org/package/generator-jhipster-vmware-clarity
[travis-image]: https://travis-ci.org/chihosin/generator-jhipster-vmware-clarity.svg?branch=master
[travis-url]: https://travis-ci.org/chihosin/generator-jhipster-vmware-clarity
[daviddm-image]: https://david-dm.org/chihosin/generator-jhipster-vmware-clarity.svg?theme=shields.io
[daviddm-url]: https://david-dm.org/chihosin/generator-jhipster-vmware-clarity

==> generator-jhipster-vmware-clarity-1.0.8.tgz: package/README.md <==
# generator-jhipster-vmware-clarity

[![NPM version][npm-image]][npm-url] [![Build Status][travis-image]][travis-url] [![Dependency Status][daviddm-image]][daviddm-url]

> JHipster module, Clarity Design System for Angular.

# Introduction

This is a [JHipster](http://jhipster.github.io/) module, that is meant to be used in a JHipster application.

# Prerequisites

As this is a [JHipster](http://jhipster.github.io/) module, we expect you have JHipster and its related tools already installed:

*   [Installing JHipster](https://jhipster.github.io/installation.html)

# Installation

## With Yarn

To install this module:

```bash
yarn global add generator-jhipster-vmware-clarity
```

To update this module:

```bash
yarn global upgrade generator-jhipster-vmware-clarity
```

## With NPM

To install this module:

```bash
npm install -g generator-jhipster-vmware-clarity
```

To update this module:

```bash
npm update -g generator-jhipster-vmware-clarity
```

# Usage

```bash
# Install UI Framework
yo jhipster-vmware-clarity

# Create entity
yo jhipster entity <entityName> --[options]
```

# License

MIT © [Chiho Sin](https://github.com/chihosin)

[npm-image]: https://img.shields.io/npm/v/generator-jhipster-vmware-clarity.svg
[npm-url]: https://npmjs.org/package/generator-jhipster-vmware-clarity
[travis-image]: https://travis-ci.org/ChihoSin/generator-jhipster-vmware-clarity.svg?branch=master
[travis-url]: https://travis-ci.org/ChihoSin/generator-jhipster-vmware-clarity
[daviddm-image]: https://david-dm.org/chihosin/generator-jhipster-vmware-clarity.svg?theme=shields.io
[daviddm-url]: https://david-dm.org/chihosin/generator-jhipster-vmware-clarity

[![Build Status](https://travis-ci.org/ChihoSin/generator-jhipster-vmware-clarity.svg?branch=master)](https://travis-ci.org/ChihoSin/generator-jhipster-vmware-clarity)
